// API client for simplyaboveaverage
class SimplyAboveAverageAPI {
  constructor() {
    this.baseUrl = "https://simplyaboveaverage.com/api"
    this.authToken = null
  }

  // Initialize the API client
  async init() {
    return new Promise((resolve) => {
      if (typeof chrome !== "undefined" && chrome.storage) {
        chrome.storage.local.get(["authToken"], (result) => {
          if (result.authToken) {
            this.authToken = result.authToken
          }
          resolve()
        })
      } else {
        console.warn("Chrome storage API not available. Running in a non-extension environment.")
        resolve()
      }
    })
  }

  // Set auth token
  setAuthToken(token) {
    this.authToken = token
    if (typeof chrome !== "undefined" && chrome.storage) {
      chrome.storage.local.set({ authToken: token })
    } else {
      console.warn("Chrome storage API not available. Cannot save auth token.")
    }
  }

  // Get auth headers
  getHeaders() {
    const headers = {
      "Content-Type": "application/json",
    }

    if (this.authToken) {
      headers["Authorization"] = `Bearer ${this.authToken}`
    }

    return headers
  }

  // Login
  async login(email, password) {
    try {
      const response = await fetch(`${this.baseUrl}/auth/login`, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({ email, password }),
      })

      const data = await response.json()

      if (data.success && data.token) {
        this.setAuthToken(data.token)
      }

      return data
    } catch (error) {
      console.error("Login error:", error)
      return { success: false, message: "Network error. Please try again." }
    }
  }

  // Logout
  logout() {
    this.authToken = null
    if (typeof chrome !== "undefined" && chrome.storage) {
      chrome.storage.local.remove(["authToken", "user"])
    } else {
      console.warn("Chrome storage API not available. Cannot remove auth token.")
    }
  }

  // Add to wishlist
  async addToWishlist(product) {
    try {
      const response = await fetch(`${this.baseUrl}/wishlist/add`, {
        method: "POST",
        headers: this.getHeaders(),
        body: JSON.stringify(product),
      })

      return await response.json()
    } catch (error) {
      console.error("Add to wishlist error:", error)
      return { success: false, message: "Network error. Please try again." }
    }
  }

  // Get wishlist items
  async getWishlist() {
    try {
      const response = await fetch(`${this.baseUrl}/wishlist/get`, {
        method: "GET",
        headers: this.getHeaders(),
      })

      return await response.json()
    } catch (error) {
      console.error("Get wishlist error:", error)
      return { success: false, message: "Network error. Please try again." }
    }
  }

  // Remove from wishlist
  async removeFromWishlist(id) {
    try {
      const response = await fetch(`${this.baseUrl}/wishlist/remove`, {
        method: "POST",
        headers: this.getHeaders(),
        body: JSON.stringify({ id }),
      })

      return await response.json()
    } catch (error) {
      console.error("Remove from wishlist error:", error)
      return { success: false, message: "Network error. Please try again." }
    }
  }

  // Add to cart
  async addToCart(product) {
    try {
      const response = await fetch(`${this.baseUrl}/cart/add`, {
        method: "POST",
        headers: this.getHeaders(),
        body: JSON.stringify(product),
      })

      return await response.json()
    } catch (error) {
      console.error("Add to cart error:", error)
      return { success: false, message: "Network error. Please try again." }
    }
  }

  // Get cart items
  async getCart() {
    try {
      const response = await fetch(`${this.baseUrl}/cart/get`, {
        method: "GET",
        headers: this.getHeaders(),
      })

      return await response.json()
    } catch (error) {
      console.error("Get cart error:", error)
      return { success: false, message: "Network error. Please try again." }
    }
  }

  // Update cart item
  async updateCartItem(id, quantity) {
    try {
      const response = await fetch(`${this.baseUrl}/cart/update`, {
        method: "POST",
        headers: this.getHeaders(),
        body: JSON.stringify({ id, quantity }),
      })

      return await response.json()
    } catch (error) {
      console.error("Update cart error:", error)
      return { success: false, message: "Network error. Please try again." }
    }
  }

  // Remove from cart
  async removeFromCart(id) {
    try {
      const response = await fetch(`${this.baseUrl}/cart/remove`, {
        method: "POST",
        headers: this.getHeaders(),
        body: JSON.stringify({ id }),
      })

      return await response.json()
    } catch (error) {
      console.error("Remove from cart error:", error)
      return { success: false, message: "Network error. Please try again." }
    }
  }

  // Clear cart
  async clearCart() {
    try {
      const response = await fetch(`${this.baseUrl}/cart/clear`, {
        method: "POST",
        headers: this.getHeaders(),
      })

      return await response.json()
    } catch (error) {
      console.error("Clear cart error:", error)
      return { success: false, message: "Network error. Please try again." }
    }
  }

  // Get user profile
  async getUserProfile() {
    try {
      const response = await fetch(`${this.baseUrl}/user/profile`, {
        method: "GET",
        headers: this.getHeaders(),
      })

      return await response.json()
    } catch (error) {
      console.error("Get user profile error:", error)
      return { success: false, message: "Network error. Please try again." }
    }
  }
  // Search products using Meilisearch (via secure backend API route)
  async searchProductsViaMeili(parsedAttributes) {
    try {
      const response = await fetch("/api/searchmeili", {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({
          query: parsedAttributes.query || "",
          size: parsedAttributes.size,
          color: parsedAttributes.color,
          inseam: parsedAttributes.inseam,
          category: parsedAttributes.category,
        }),
      })
      const data = await response.json()
      return data.hits || []
    } catch (error) {
      console.error("Meili search error:", error)
      return []
    }
  }
  

}

// Export the API client
window.SimplyAboveAverageAPI = new SimplyAboveAverageAPI()
