// This script runs on every page the user visits

// Listen for messages from the popup or background script
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
  if (request.action === "extractProductInfo") {
    const productInfo = extractProductInfo()
    sendResponse({ success: true, product: productInfo })
    return true
  }
})

// Function to extract product information from the page
function extractProductInfo() {
  // Initialize product object
  const product = {
    title: null,
    price: null,
    imageUrl: null,
    vendor: null,
    url: window.location.href,
    sizes: [],
    colors: [],
  }

  // Try to extract product information using common patterns

  // 1. Extract title
  const possibleTitleElements = [
    document.querySelector("h1"),
    document.querySelector(".product-title"),
    document.querySelector(".product-name"),
    document.querySelector("[data-product-title]"),
    document.querySelector('[itemprop="name"]'),
  ]

  for (const element of possibleTitleElements) {
    if (element && element.textContent.trim()) {
      product.title = element.textContent.trim()
      break
    }
  }

  // 2. Extract price
  const possiblePriceElements = [
    document.querySelector(".product-price"),
    document.querySelector(".price"),
    document.querySelector("[data-product-price]"),
    document.querySelector('[itemprop="price"]'),
    document.querySelector(".product__price"),
  ]

  for (const element of possiblePriceElements) {
    if (element && element.textContent.trim()) {
      product.price = element.textContent.trim()
      break
    }
  }

  // 3. Extract image URL
  const possibleImageElements = [
    document.querySelector(".product-image img"),
    document.querySelector(".product__image img"),
    document.querySelector("[data-product-image] img"),
    document.querySelector('[itemprop="image"]'),
    document.querySelector(".product-featured-image"),
  ]

  for (const element of possibleImageElements) {
    if (element && element.src) {
      product.imageUrl = element.src
      break
    }
  }

  // 4. Extract vendor/brand
  const possibleVendorElements = [
    document.querySelector(".product-vendor"),
    document.querySelector(".brand"),
    document.querySelector("[data-product-vendor]"),
    document.querySelector('[itemprop="brand"]'),
  ]

  for (const element of possibleVendorElements) {
    if (element && element.textContent.trim()) {
      product.vendor = element.textContent.trim()
      break
    }
  }

  // If vendor is not found, try to extract from URL or title
  if (!product.vendor) {
    // Extract from URL
    const hostname = window.location.hostname
    const domainParts = hostname.split(".")
    if (domainParts.length >= 2) {
      product.vendor =
        domainParts[domainParts.length - 2].charAt(0).toUpperCase() + domainParts[domainParts.length - 2].slice(1)
    }
  }

  // 5. Extract available sizes
  const possibleSizeElements = [
    document.querySelectorAll(".product-size option"),
    document.querySelectorAll(".size-option"),
    document.querySelectorAll("[data-product-size]"),
    document.querySelectorAll(".swatch-size .swatch-element"),
  ]

  for (const elements of possibleSizeElements) {
    if (elements && elements.length > 0) {
      elements.forEach((element) => {
        const size = element.textContent.trim() || element.value
        if (size && !product.sizes.includes(size)) {
          product.sizes.push(size)
        }
      })
      if (product.sizes.length > 0) break
    }
  }

  // 6. Extract available colors
  const possibleColorElements = [
    document.querySelectorAll(".product-color option"),
    document.querySelectorAll(".color-option"),
    document.querySelectorAll("[data-product-color]"),
    document.querySelectorAll(".swatch-color .swatch-element"),
  ]

  for (const elements of possibleColorElements) {
    if (elements && elements.length > 0) {
      elements.forEach((element) => {
        const color = element.textContent.trim() || element.value
        if (color && !product.colors.includes(color)) {
          product.colors.push(color)
        }
      })
      if (product.colors.length > 0) break
    }
  }

  return product
}

// Check if the current page is a product page
function isProductPage() {
  // Common indicators of a product page
  const productPageIndicators = [
    // URL patterns
    /\/product\//i,
    /\/products\//i,
    /\/item\//i,

    // DOM elements
    document.querySelector(".product-details"),
    document.querySelector(".product-page"),
    document.querySelector("[data-product-id]"),
    document.querySelector('form[action*="cart/add"]'),
    document.querySelector('button[name="add"]'),
    document.querySelector(".add-to-cart"),
  ]

  // Check URL patterns
  for (let i = 0; i < 3; i++) {
    if (productPageIndicators[i].test(window.location.href)) {
      return true
    }
  }

  // Check DOM elements
  for (let i = 3; i < productPageIndicators.length; i++) {
    if (productPageIndicators[i]) {
      return true
    }
  }

  return false
}

// If this is a product page, extract the info and send it to the background script
if (isProductPage()) {
  const productInfo = extractProductInfo()

  // Only send if we have at least a title or image
  if (productInfo.title || productInfo.imageUrl) {
    if (typeof chrome !== "undefined" && chrome.runtime) {
      chrome.runtime.sendMessage({
        action: "saveProduct",
        product: productInfo,
      })
    } else {
      console.warn("Chrome runtime is not available.")
    }
  }
}
