document.addEventListener("DOMContentLoaded", async () => {
  // Initialize API client
  await window.SimplyAboveAverageAPI.init()

  // DOM elements
  const loginSection = document.getElementById("login-section")
  const productSection = document.getElementById("product-section")
  const successSection = document.getElementById("success-section")
  const errorSection = document.getElementById("error-section")
  const logoutButton = document.getElementById("logout-button")
  const loginForm = document.getElementById("login-form")
  const authMessage = document.getElementById("auth-message")

  // Product elements
  const productImage = document.getElementById("product-image")
  const productTitle = document.getElementById("product-title")
  const productPrice = document.getElementById("product-price")
  const productVendor = document.getElementById("product-vendor")
  const sizeSelect = document.getElementById("size-select")
  const colorSelect = document.getElementById("color-select")

  // Action buttons
  const addToWishlistBtn = document.getElementById("add-to-wishlist")
  const addToCartBtn = document.getElementById("add-to-cart")
  const viewWishlistBtn = document.getElementById("view-wishlist")
  const viewCartBtn = document.getElementById("view-cart")
  const continueShoppingBtn = document.getElementById("continue-shopping")
  const tryAgainBtn = document.getElementById("try-again")

  // Check if user is logged in
  checkAuthStatus()

  // Check if there's a product on the current page
  getCurrentTabProduct()

  // Event listeners
  loginForm.addEventListener("submit", handleLogin)
  logoutButton.addEventListener("click", handleLogout)
  addToWishlistBtn.addEventListener("click", addToWishlist)
  addToCartBtn.addEventListener("click", addToCart)
  viewWishlistBtn.addEventListener("click", () => openTab("https://simplyaboveaverage.com/wishlist"))
  viewCartBtn.addEventListener("click", () => openTab("https://simplyaboveaverage.com/cart"))
  continueShoppingBtn.addEventListener("click", resetUI)
  tryAgainBtn.addEventListener("click", resetUI)

  // Functions
  function checkAuthStatus() {
    chrome.storage.local.get(["authToken", "user"], (result) => {
      if (result.authToken && result.user) {
        // User is logged in
        loginSection.classList.add("hidden")
        logoutButton.classList.remove("hidden")

        // Check if we have a product to show
        chrome.storage.local.get(["currentProduct"], (data) => {
          if (data.currentProduct) {
            showProductSection(data.currentProduct)
          }
        })
      } else {
        // User is not logged in
        loginSection.classList.remove("hidden")
        productSection.classList.add("hidden")
        logoutButton.classList.add("hidden")
      }
    })
  }

  async function handleLogin(e) {
    e.preventDefault()
    const email = document.getElementById("email").value
    const password = document.getElementById("password").value

    // Show loading state
    const submitBtn = loginForm.querySelector('button[type="submit"]')
    const originalText = submitBtn.textContent
    submitBtn.textContent = "Signing in..."
    submitBtn.disabled = true

    try {
      // Call the API to authenticate
      const result = await window.SimplyAboveAverageAPI.login(email, password)

      if (result.success) {
        // Store user info
        chrome.storage.local.set(
          {
            user: result.user,
          },
          () => {
            // Reset form and check auth status again
            loginForm.reset()
            checkAuthStatus()
          },
        )
      } else {
        // Show error message
        authMessage.textContent = result.message || "Invalid email or password"
      }
    } catch (error) {
      console.error("Login error:", error)
      authMessage.textContent = "An error occurred. Please try again."
    } finally {
      // Reset button state
      submitBtn.textContent = originalText
      submitBtn.disabled = false
    }
  }

  function handleLogout() {
    // Clear stored auth data
    window.SimplyAboveAverageAPI.logout()
    checkAuthStatus()
  }

  function getCurrentTabProduct() {
    chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
      const currentTab = tabs[0]

      // Execute content script to extract product info
      chrome.scripting.executeScript(
        {
          target: { tabId: currentTab.id },
          function: extractProductInfo,
        },
        (results) => {
          if (results && results[0] && results[0].result) {
            const productInfo = results[0].result

            // Store the product info
            chrome.storage.local.set({ currentProduct: productInfo })

            // Check if user is logged in before showing product
            chrome.storage.local.get(["authToken"], (result) => {
              if (result.authToken) {
                showProductSection(productInfo)
              }
            })
          }
        },
      )
    })
  }

  function showProductSection(productInfo) {
    // Update product details
    productImage.src = productInfo.imageUrl || "placeholder.png"
    productTitle.textContent = productInfo.title || "Unknown Product"
    productPrice.textContent = productInfo.price || "$0.00"
    productVendor.textContent = productInfo.vendor || "Unknown Vendor"

    // Populate size options
    if (productInfo.sizes && productInfo.sizes.length > 0) {
      sizeSelect.innerHTML = '<option value="">-- Select Size --</option>'
      productInfo.sizes.forEach((size) => {
        const option = document.createElement("option")
        option.value = size
        option.textContent = size
        sizeSelect.appendChild(option)
      })
    }

    // Populate color options
    if (productInfo.colors && productInfo.colors.length > 0) {
      colorSelect.innerHTML = '<option value="">-- Select Color --</option>'
      productInfo.colors.forEach((color) => {
        const option = document.createElement("option")
        option.value = color
        option.textContent = color
        colorSelect.appendChild(option)
      })
    }

    // Show product section
    loginSection.classList.add("hidden")
    productSection.classList.remove("hidden")
    successSection.classList.add("hidden")
    errorSection.classList.add("hidden")
  }

  async function addToWishlist() {
    const size = sizeSelect.value
    const color = colorSelect.value

    chrome.storage.local.get(["currentProduct"], async (data) => {
      if (!data.currentProduct) {
        showError("Product information missing")
        return
      }

      const product = {
        ...data.currentProduct,
        size: size || null,
        color: color || null,
      }

      try {
        // Call API to add to wishlist
        const result = await window.SimplyAboveAverageAPI.addToWishlist(product)

        if (result.success) {
          showSuccess("Product added to your wishlist!", "wishlist")
        } else {
          showError(result.message || "Failed to add product to wishlist")
        }
      } catch (error) {
        console.error("Wishlist error:", error)
        showError("An error occurred. Please try again.")
      }
    })
  }

  async function addToCart() {
    const size = sizeSelect.value
    const color = colorSelect.value

    chrome.storage.local.get(["currentProduct"], async (data) => {
      if (!data.currentProduct) {
        showError("Product information missing")
        return
      }

      const product = {
        ...data.currentProduct,
        size: size || null,
        color: color || null,
        quantity: 1,
      }

      try {
        // Call API to add to cart
        const result = await window.SimplyAboveAverageAPI.addToCart(product)

        if (result.success) {
          showSuccess("Product added to your cart!", "cart")
        } else {
          showError(result.message || "Failed to add product to cart")
        }
      } catch (error) {
        console.error("Cart error:", error)
        showError("An error occurred. Please try again.")
      }
    })
  }

  function showSuccess(message, type) {
    document.getElementById("success-text").textContent = message

    // Show/hide appropriate buttons based on type
    if (type === "wishlist") {
      viewWishlistBtn.classList.remove("hidden")
      viewCartBtn.classList.add("hidden")
    } else if (type === "cart") {
      viewWishlistBtn.classList.add("hidden")
      viewCartBtn.classList.remove("hidden")
    } else {
      viewWishlistBtn.classList.remove("hidden")
      viewCartBtn.classList.remove("hidden")
    }

    // Show success section
    loginSection.classList.add("hidden")
    productSection.classList.add("hidden")
    successSection.classList.remove("hidden")
    errorSection.classList.add("hidden")
  }

  function showError(message) {
    document.getElementById("error-text").textContent = message

    // Show error section
    loginSection.classList.add("hidden")
    productSection.classList.add("hidden")
    successSection.classList.add("hidden")
    errorSection.classList.remove("hidden")
  }

  function resetUI() {
    // Go back to product section
    chrome.storage.local.get(["authToken", "currentProduct"], (result) => {
      if (result.authToken && result.currentProduct) {
        showProductSection(result.currentProduct)
      } else if (result.authToken) {
        loginSection.classList.add("hidden")
        productSection.classList.add("hidden")
        successSection.classList.add("hidden")
        errorSection.classList.add("hidden")
      } else {
        checkAuthStatus()
      }
    })
  }

  function openTab(url) {
    chrome.tabs.create({ url })
  }
})

// This function will be injected into the page to extract product information
function extractProductInfo() {
  // Initialize product object
  const product = {
    title: null,
    price: null,
    imageUrl: null,
    vendor: null,
    url: window.location.href,
    sizes: [],
    colors: [],
  }

  // Try to extract product information using common patterns

  // 1. Extract title
  const possibleTitleElements = [
    document.querySelector("h1"),
    document.querySelector(".product-title"),
    document.querySelector(".product-name"),
    document.querySelector("[data-product-title]"),
    document.querySelector('[itemprop="name"]'),
  ]

  for (const element of possibleTitleElements) {
    if (element && element.textContent.trim()) {
      product.title = element.textContent.trim()
      break
    }
  }

  // 2. Extract price
  const possiblePriceElements = [
    document.querySelector(".product-price"),
    document.querySelector(".price"),
    document.querySelector("[data-product-price]"),
    document.querySelector('[itemprop="price"]'),
    document.querySelector(".product__price"),
  ]

  for (const element of possiblePriceElements) {
    if (element && element.textContent.trim()) {
      product.price = element.textContent.trim()
      break
    }
  }

  // 3. Extract image URL
  const possibleImageElements = [
    document.querySelector(".product-image img"),
    document.querySelector(".product__image img"),
    document.querySelector("[data-product-image] img"),
    document.querySelector('[itemprop="image"]'),
    document.querySelector(".product-featured-image"),
  ]

  for (const element of possibleImageElements) {
    if (element && element.src) {
      product.imageUrl = element.src
      break
    }
  }

  // 4. Extract vendor/brand
  const possibleVendorElements = [
    document.querySelector(".product-vendor"),
    document.querySelector(".brand"),
    document.querySelector("[data-product-vendor]"),
    document.querySelector('[itemprop="brand"]'),
  ]

  for (const element of possibleVendorElements) {
    if (element && element.textContent.trim()) {
      product.vendor = element.textContent.trim()
      break
    }
  }

  // If vendor is not found, try to extract from URL or title
  if (!product.vendor) {
    // Extract from URL
    const hostname = window.location.hostname
    const domainParts = hostname.split(".")
    if (domainParts.length >= 2) {
      product.vendor =
        domainParts[domainParts.length - 2].charAt(0).toUpperCase() + domainParts[domainParts.length - 2].slice(1)
    }
  }

  // 5. Extract available sizes
  const possibleSizeElements = [
    document.querySelectorAll(".product-size option"),
    document.querySelectorAll(".size-option"),
    document.querySelectorAll("[data-product-size]"),
    document.querySelectorAll(".swatch-size .swatch-element"),
  ]

  for (const elements of possibleSizeElements) {
    if (elements && elements.length > 0) {
      elements.forEach((element) => {
        const size = element.textContent.trim() || element.value
        if (size && !product.sizes.includes(size)) {
          product.sizes.push(size)
        }
      })
      if (product.sizes.length > 0) break
    }
  }

  // 6. Extract available colors
  const possibleColorElements = [
    document.querySelectorAll(".product-color option"),
    document.querySelectorAll(".color-option"),
    document.querySelectorAll("[data-product-color]"),
    document.querySelectorAll(".swatch-color .swatch-element"),
  ]

  for (const elements of possibleColorElements) {
    if (elements && elements.length > 0) {
      elements.forEach((element) => {
        const color = element.textContent.trim() || element.value
        if (color && !product.colors.includes(color)) {
          product.colors.push(color)
        }
      })
      if (product.colors.length > 0) break
    }
  }

  return product
}
